==> driza-0.6.3.tar.gz: driza-0.6.3/Driza/textrender.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#

#Copyright (C) 2006  Néstor Arocha Rodríguez,Inmaculada Luengo Merino 

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""Modulo de clases que ayudan al renderizado del texto"""

from qt import QString

class FloatRender:
    def __init__(self,configuracion):
        self.__config=configuracion

    def render(self,numero,decimales=None):
        """Devuelve una ristra que representa al numero con el numero de decimales indicados o el de la configuracion.
        numero puede ser un float, un str, un unicode o un Real"""
        if decimales:
            dec = decimales
        else:
            dec = self.__config.configuracion["decimales"]
        cadena = "%."+str(dec)+"f"
        if isinstance(numero,float):
            return cadena % (numero)
        if isinstance(numero,str) or isinistance(numero,unicode):
            return cadena % (float(numero))
        if isinstance(numero,QString):
            return cadena % (float(numero.latin1()))

==> driza-0.6.4.tar.gz: driza-0.6.4/Driza/textrender.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#

#Copyright (C) 2006  Néstor Arocha Rodríguez,Inmaculada Luengo Merino 

#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""Modulo de clases que ayudan al renderizado del texto"""

from qt import QString

class FloatRender:
    def __init__(self,configuracion):
        self.__config=configuracion

    def render(self,numero,decimales=None):
        """Devuelve una ristra que representa al numero con el numero de decimales indicados o el de la configuracion.
        numero puede ser un float, un str, un unicode o un Real"""
        if decimales:
            dec = decimales
        else:
            dec = self.__config.configuracion["decimales"]
        cadena = "%."+str(dec)+"f"
        if isinstance(numero,float):
            return cadena % (numero)
        if isinstance(numero,str) or isinstance(numero,unicode):
            return cadena % (float(numero))
        if isinstance(numero,QString):
            return cadena % (float(numero.latin1()))
        else:
            print "EEERRRORR"
